/* gen.c - Generate cases for the synthetic dataset "add10" suggested by Jerome
 * H. Friedman in "Multivariate Adaptive Regression Splines", technical Report
 * No. 102, November 1988, Laboratory for Computational Statistics, Department
 * of Statistics, Stanford University.
 *
 * The function is:
 * f(x1,...,x10) = 10*sin(pi*x1*x2) + 20*(x3-0.5)^2 + 10*x4 + 5*x5 + n,
 * where n is zero mean unit variance Gaussian noise. The inputs x1...x10
 * are sampled independently from a uniform [0; 1] distribution. */

#include <stdlib.h>
#include <math.h>
#include <stdio.h>

/* Adjustable parameters */

#define Seed 1                                  /* Random number seed to use */
#define N_cases 9792                          /* Number of cases to generate */

double ranu(void)                             /* generate [0.0, 1.0) uniform */
{
  return drand48();
}

double rann(void)                 /* generate zero mean unit variance normal */
{
  double a, b;
  
  a = ranu();
  b = ranu();
  return cos(2.0*M_PI*a)*sqrt(-2.0*log(b));
}

main(void)
{
  int    i, j;
  double x[10], y;

  srand48(Seed);                                                 /* set seed */
  for (i=0; i<N_cases; i++) {

    for (j=0; j<10; j++)                                  /* generate inputs */
      x[j] = ranu();

    y = 10.0*sin(M_PI*x[0]*x[1])             /* compute noisy function value */
      + 20.0*(x[2]-0.5)*(x[2]-0.5)
      + 10.0*x[3]
      + 5.0*x[4]
      + rann();

    for (j=0; j<10; j++)                                  /* print out cases */
      printf("%10.6f ", x[j]);
    printf("%10.6f\n", y);
  }
 
  exit(0);
}


